aboutsummaryrefslogtreecommitdiffstats
path: root/OpenAL32/Include/alMain.h
diff options
context:
space:
mode:
Diffstat (limited to 'OpenAL32/Include/alMain.h')
-rw-r--r--OpenAL32/Include/alMain.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/OpenAL32/Include/alMain.h b/OpenAL32/Include/alMain.h
index 2f1eb850..63787251 100644
--- a/OpenAL32/Include/alMain.h
+++ b/OpenAL32/Include/alMain.h
@@ -677,9 +677,10 @@ struct ALCdevice_struct
ALuint64 ClockBase;
ALuint SamplesDone;
- /* Temp storage used for mixing. */
- alignas(16) ALfloat SampleData1[BUFFERSIZE];
- alignas(16) ALfloat SampleData2[BUFFERSIZE];
+ /* Temp storage used for each source when mixing. */
+ alignas(16) ALfloat SourceData[BUFFERSIZE];
+ alignas(16) ALfloat ResampledData[BUFFERSIZE];
+ alignas(16) ALfloat FilteredData[BUFFERSIZE];
// Dry path buffer mix
alignas(16) ALfloat DryBuffer[MaxChannels][BUFFERSIZE];